==> script.module.nanscrapers-0.5.4.zip: script.module.nanscrapers/lib/nanscrapers/scraperplugins/watchcartoons.py <==
import re
import requests
import xbmc
from nanscrapers.scraper import Scraper


class Watchcartoons(Scraper):
    name = "watchcartoon"
    domains = ['watchcartoononline.io']
    sources = []

    def __init__(self):
        self.base_link_cartoons = 'http://www.watchcartoononline.io/cartoon-list'
        self.base_link_movies = 'https://www.watchcartoononline.io/movie-list'
        
    def scrape_episode(self, title, show_year, year, season, episode, imdb, tvdb):
        try:
            html = requests.get(self.base_link_cartoons).text
            match = re.compile('<a href="(.+?)" title=".+?">(.+?)</a>').findall(html)
            for url, name in match:
                if title.replace(' ', '').replace('amp;', '').replace('\'').lower() == name.replace(' ', '').replace('amp;','').replace('\'','').lower():
                    html2 = requests.get(url).text
                    match2 = re.compile(
                        '<li><a href="(.+?)" rel="bookmark" title=".+?" class="sonra">(.+?)</a>').findall(html2)
                    for url2, name in match2:
                        episode_check = 'episode-' + str(episode)
                        season_check = 'season-' + str(season)
                        if season_check in url2.lower():
                            if episode_check in url2.lower():
                                self.check_for_play(url2, title, show_year, year, season, episode)
                        if not 'season' in url2:
                            if episode_check in url2.lower():
                                self.check_for_play(url2, title, show_year, year, season, episode)
            return self.sources

        except:
            return []
            pass

    def scrape_movie(self, title, year, imdb):
        try:
            html = requests.get(self.base_link_movies).text
            match = re.compile('<a href="(.+?)" title=".+?">(.+?)</a>').findall(html)
            for url, name in match:
                clean_title = title.replace(' ', '').replace('amp;', '').replace('&#8217;','\'').replace('\'','').lower()
                clean_name = name.replace('&#8217;','\'').replace(' ', '').replace('amp;','').replace('\'','').lower()
                if clean_title in clean_name:
                    self.check_for_play(url,title,'',year,'','')
            return self.sources

        except:
            return []
            pass


    def check_for_play(self, url2, title, show_year, year, season, episode):
        try:
            mobile_url = url2.replace('www', 'm')
            html3 = requests.get(mobile_url, verify=False).text
            match_playlink = re.compile('<source src="(.+?)"').findall(html3)
            for playlink in match_playlink:
                self.sources.append(
                    {'source': 'watchcartoons', 'quality': 'SD', 'scraper': self.name, 'url': playlink, 'direct': True})
        except:
            pass

==> script.module.nanscrapers-0.5.7.zip: script.module.nanscrapers/lib/nanscrapers/scraperplugins/watchcartoons.py <==
import re
import requests
import xbmc
from nanscrapers.scraper import Scraper


class Watchcartoons(Scraper):
    name = "watchcartoon"
    domains = ['watchcartoononline.io']
    sources = []

    def __init__(self):
        self.base_link_cartoons = 'http://www.watchcartoononline.io/cartoon-list'
        self.base_link_movies = 'https://www.watchcartoononline.io/movie-list'
        
    def scrape_episode(self, title, show_year, year, season, episode, imdb, tvdb):
        try:
            html = requests.get(self.base_link_cartoons).text
            match = re.compile('<a href="(.+?)" title=".+?">(.+?)</a>').findall(html)
            for url, name in match:
                if title.replace(' ', '').replace('amp;', '').replace('\'','').lower() == name.replace(' ', '').replace('amp;','').replace('\'','').lower():
                    html2 = requests.get(url).text
                    match2 = re.compile(
                        '<li><a href="(.+?)" rel="bookmark" title=".+?" class="sonra">(.+?)</a>').findall(html2)
                    for url2, name in match2:
                        episode_check = 'episode-' + str(episode)
                        season_check = 'season-' + str(season)
                        if season_check in url2.lower():
                            if episode_check in url2.lower():
                                self.check_for_play(url2, title, show_year, year, season, episode)
                        if not 'season' in url2:
                            if episode_check in url2.lower():
                                self.check_for_play(url2, title, show_year, year, season, episode)
            return self.sources

        except:
            return []
            pass

    def scrape_movie(self, title, year, imdb):
        try:
            html = requests.get(self.base_link_movies).text
            match = re.compile('<a href="(.+?)" title=".+?">(.+?)</a>').findall(html)
            for url, name in match:
                clean_title = title.replace(' ', '').replace('amp;', '').replace('&#8217;','\'').replace('\'','').lower()
                clean_name = name.replace('&#8217;','\'').replace(' ', '').replace('amp;','').replace('\'','').lower()
                if clean_title in clean_name:
                    new_url = 'https://www.watchcartoononline.io/'+title.replace(' ','-')
                    self.check_for_play(url,title,'',year,'','')
            return self.sources

        except:
            return []
            pass


    def check_for_play(self, url2, title, show_year, year, season, episode):
        try:
            mobile_url = url2.replace('www', 'm')
            html3 = requests.get(mobile_url, verify=False).text
            match_playlink = re.compile('<source src="(.+?)"').findall(html3)
            for playlink in match_playlink:
                self.sources.append(
                    {'source': 'watchcartoons', 'quality': 'SD', 'scraper': self.name, 'url': playlink, 'direct': True})
        except:
            pass
